# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataRefreshSchedule(Model):
    """Represents a refresh schedule for the state machine.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar is_active: Gets a value indicating whether the schedule is active.
    :vartype is_active: bool
    :ivar timezone_id: Gets the ID of the timezone
    :vartype timezone_id: str
    :ivar cron_schedules: Gets the schedule in CRON format
    :vartype cron_schedules: list[str]
    :ivar schedule_id: Gets the ID of the schedule
    :vartype schedule_id: str
    :ivar instance_id: Gets the Customer Insights instance id associated with
     this object.
    :vartype instance_id: str
    """

    _validation = {
        'is_active': {'readonly': True},
        'timezone_id': {'readonly': True},
        'cron_schedules': {'readonly': True},
        'schedule_id': {'readonly': True},
        'instance_id': {'readonly': True},
    }

    _attribute_map = {
        'is_active': {'key': 'isActive', 'type': 'bool'},
        'timezone_id': {'key': 'timezoneId', 'type': 'str'},
        'cron_schedules': {'key': 'cronSchedules', 'type': '[str]'},
        'schedule_id': {'key': 'scheduleId', 'type': 'str'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs) -> None:
        super(DataRefreshSchedule, self).__init__(**kwargs)
        self.is_active = None
        self.timezone_id = None
        self.cron_schedules = None
        self.schedule_id = None
        self.instance_id = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AttributeSearchConfiguration(Model):
    """AttributeSearchConfiguration.

    :param name: Gets the attribute name.
    :type name: str
    :param properties:
    :type properties:
     ~dynamics.customerinsights.api.models.AttributeSearchProperties
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'properties': {'key': 'properties', 'type': 'AttributeSearchProperties'},
    }

    def __init__(self, *, name: str=None, properties=None, **kwargs) -> None:
        super(AttributeSearchConfiguration, self).__init__(**kwargs)
        self.name = name
        self.properties = properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ResourceMetadata(Model):
    """Represents a Resource metadata.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param kind: Possible values include: 'bearerAuthenticationConnection',
     'sshKeyAuthenticationConnection', 'apiKeyAuthenticationConnection',
     'basicAuthenticationConnection', 'adlsGen2', 'd365Sales', 'd365Marketing',
     'attachCds', 'ftp', 'facebookAds', 'http', 'mailchimp', 'googleAds',
     'marketo'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :ivar resource_id: Gets the Id of the resource.
    :vartype resource_id: str
    :ivar operation_id: Gets the Id of the operation being performed on the
     resource.
    :vartype operation_id: str
    :param resource_type: Possible values include: 'adlsGen2', 'd365Sales',
     'cds', 'ftp', 'bearerAuthenticationConnection',
     'sshKeyAuthenticationConnection', 'apiKeyAuthenticationConnection',
     'basicAuthenticationConnection', 'facebookAds', 'http', 'mailchimp',
     'googleAds', 'marketo'
    :type resource_type: str or ~dynamics.customerinsights.api.models.enum
    :ivar name: Gets the Name of the resource.
    :vartype name: str
    :ivar description: Gets the Description of the resource.
    :vartype description: str
    :ivar version: Gets the version number of this object.
    :vartype version: long
    :ivar updated_by: Gets the UPN of the user who last updated this record.
    :vartype updated_by: str
    :ivar updated_utc: Gets the time the object was last updated.
    :vartype updated_utc: datetime
    :ivar created_by: Gets the email address of the user who created this
     record.
    :vartype created_by: str
    :ivar created_utc: Gets the time the object was initially created.
    :vartype created_utc: datetime
    :ivar instance_id: Gets the Customer Insights instance id associated with
     this object.
    :vartype instance_id: str
    """

    _validation = {
        'resource_id': {'readonly': True},
        'operation_id': {'readonly': True},
        'name': {'readonly': True},
        'description': {'readonly': True},
        'version': {'readonly': True},
        'updated_by': {'readonly': True},
        'updated_utc': {'readonly': True},
        'created_by': {'readonly': True},
        'created_utc': {'readonly': True},
        'instance_id': {'readonly': True},
    }

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'resource_id': {'key': 'resourceId', 'type': 'str'},
        'operation_id': {'key': 'operationId', 'type': 'str'},
        'resource_type': {'key': 'resourceType', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ResourceMetadata, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.resource_id = None
        self.operation_id = None
        self.resource_type = kwargs.get('resource_type', None)
        self.name = None
        self.description = None
        self.version = None
        self.updated_by = None
        self.updated_utc = None
        self.created_by = None
        self.created_utc = None
        self.instance_id = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IRelationshipMetadata(Model):
    """IRelationshipMetadata.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar name:
    :vartype name: str
    :ivar friendly_name:
    :vartype friendly_name: str
    :param from_attribute:
    :type from_attribute:
     ~dynamics.customerinsights.api.models.IAttributeMetadata
    :param to_attribute:
    :type to_attribute:
     ~dynamics.customerinsights.api.models.IAttributeMetadata
    :param relationship_type: Possible values include:
     'singleKeyRelationshipOrigin', 'singleKeyRelationshipDestination',
     'dataSourceLineageOrigin', 'dataSourceLineageDestination'
    :type relationship_type: str or ~dynamics.customerinsights.api.models.enum
    :param data_source_entity:
    :type data_source_entity:
     ~dynamics.customerinsights.api.models.IEntityMetadata
    :ivar data_source_mapping_attributes:
    :vartype data_source_mapping_attributes:
     list[~dynamics.customerinsights.api.models.IAttributeMetadata]
    """

    _validation = {
        'name': {'readonly': True},
        'friendly_name': {'readonly': True},
        'data_source_mapping_attributes': {'readonly': True},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'from_attribute': {'key': 'fromAttribute', 'type': 'IAttributeMetadata'},
        'to_attribute': {'key': 'toAttribute', 'type': 'IAttributeMetadata'},
        'relationship_type': {'key': 'relationshipType', 'type': 'str'},
        'data_source_entity': {'key': 'dataSourceEntity', 'type': 'IEntityMetadata'},
        'data_source_mapping_attributes': {'key': 'dataSourceMappingAttributes', 'type': '[IAttributeMetadata]'},
    }

    def __init__(self, *, from_attribute=None, to_attribute=None, relationship_type=None, data_source_entity=None, **kwargs) -> None:
        super(IRelationshipMetadata, self).__init__(**kwargs)
        self.name = None
        self.friendly_name = None
        self.from_attribute = from_attribute
        self.to_attribute = to_attribute
        self.relationship_type = relationship_type
        self.data_source_entity = data_source_entity
        self.data_source_mapping_attributes = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityDependency(Model):
    """Represents a reference to an entity.

    :param qualified_entity_name: Gets the qualified entity name.
    :type qualified_entity_name: str
    :param type: Possible values include: 'unspecified', 'profile',
     'conflationMap', 'activity', 'aggregateKpi', 'profileKpi',
     'unifiedActivity', 'segment', 'intelligence', 'genericPrediction',
     'enrichment', 'insights', 'derivedEntity', 'quarantine'
    :type type: str or ~dynamics.customerinsights.api.models.enum
    :param attribute_names: Gets the list of attributes included in the
     dependency.
    :type attribute_names: list[str]
    :param relationship_names: Gets the list of relationships included in the
     dependency
    :type relationship_names: list[str]
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'attribute_names': {'key': 'attributeNames', 'type': '[str]'},
        'relationship_names': {'key': 'relationshipNames', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(EntityDependency, self).__init__(**kwargs)
        self.qualified_entity_name = kwargs.get('qualified_entity_name', None)
        self.type = kwargs.get('type', None)
        self.attribute_names = kwargs.get('attribute_names', None)
        self.relationship_names = kwargs.get('relationship_names', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiError(Model):
    """ApiError.

    :param error_code: Possible values include: 'notFound',
     'ambiguousReference', 'malformedInput', 'serviceUnavailable',
     'badRequest', 'notAllowed', 'conflict', 'locked', 'forbidden'
    :type error_code: str or ~dynamics.customerinsights.api.models.enum
    :param message:
    :type message: str
    """

    _attribute_map = {
        'error_code': {'key': 'errorCode', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ApiError, self).__init__(**kwargs)
        self.error_code = kwargs.get('error_code', None)
        self.message = kwargs.get('message', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstanceMetadata(Model):
    """The instance metadata.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param name: Gets the user defined instance name.
    :type name: str
    :param provisioning_state: Possible values include: 'new', 'creating',
     'active', 'createFailed', 'updateFailed', 'deleting',
     'refreshCredentials', 'resetInstanceInProgress'
    :type provisioning_state: str or
     ~dynamics.customerinsights.api.models.enum
    :param instance_type: Possible values include: 'trial', 'sandbox',
     'production'
    :type instance_type: str or ~dynamics.customerinsights.api.models.enum
    :param refresh_schedule:
    :type refresh_schedule:
     ~dynamics.customerinsights.api.models.DataRefreshSchedule
    :param expiry_time_utc: Gets the time the instance is set to expire.
    :type expiry_time_utc: datetime
    :param region: Gets the Azure region where the instance lives.
    :type region: str
    :param cds_org_info:
    :type cds_org_info: ~dynamics.customerinsights.api.models.CdsOrgInfo
    :param cds_mdl_info:
    :type cds_mdl_info: ~dynamics.customerinsights.api.models.CdsMdlInfo
    :param max_trial_extensions_allowed: Gets the total number of extensions
     allowed if this is trial instance
    :type max_trial_extensions_allowed: int
    :param trial_extension_history: Stores the details of trial extensions
     done if this is a trial instance
    :type trial_extension_history: str
    :ivar version: Gets the version number of this object.
    :vartype version: long
    :ivar updated_by: Gets the UPN of the user who last updated this record.
    :vartype updated_by: str
    :ivar updated_utc: Gets the time the object was last updated.
    :vartype updated_utc: datetime
    :ivar created_by: Gets the email address of the user who created this
     record.
    :vartype created_by: str
    :ivar created_utc: Gets the time the object was initially created.
    :vartype created_utc: datetime
    :ivar instance_id: Gets the Customer Insights instance id associated with
     this object.
    :vartype instance_id: str
    """

    _validation = {
        'version': {'readonly': True},
        'updated_by': {'readonly': True},
        'updated_utc': {'readonly': True},
        'created_by': {'readonly': True},
        'created_utc': {'readonly': True},
        'instance_id': {'readonly': True},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'provisioning_state': {'key': 'provisioningState', 'type': 'str'},
        'instance_type': {'key': 'instanceType', 'type': 'str'},
        'refresh_schedule': {'key': 'refreshSchedule', 'type': 'DataRefreshSchedule'},
        'expiry_time_utc': {'key': 'expiryTimeUtc', 'type': 'iso-8601'},
        'region': {'key': 'region', 'type': 'str'},
        'cds_org_info': {'key': 'cdsOrgInfo', 'type': 'CdsOrgInfo'},
        'cds_mdl_info': {'key': 'cdsMdlInfo', 'type': 'CdsMdlInfo'},
        'max_trial_extensions_allowed': {'key': 'maxTrialExtensionsAllowed', 'type': 'int'},
        'trial_extension_history': {'key': 'trialExtensionHistory', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, name: str=None, provisioning_state=None, instance_type=None, refresh_schedule=None, expiry_time_utc=None, region: str=None, cds_org_info=None, cds_mdl_info=None, max_trial_extensions_allowed: int=None, trial_extension_history: str=None, **kwargs) -> None:
        super(InstanceMetadata, self).__init__(**kwargs)
        self.name = name
        self.provisioning_state = provisioning_state
        self.instance_type = instance_type
        self.refresh_schedule = refresh_schedule
        self.expiry_time_utc = expiry_time_utc
        self.region = region
        self.cds_org_info = cds_org_info
        self.cds_mdl_info = cds_mdl_info
        self.max_trial_extensions_allowed = max_trial_extensions_allowed
        self.trial_extension_history = trial_extension_history
        self.version = None
        self.updated_by = None
        self.updated_utc = None
        self.created_by = None
        self.created_utc = None
        self.instance_id = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeasureVariable(Model):
    """Represents a variable (computed column) in a measure.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param kind: Possible values include: 'arithmetic', 'date'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :ivar name: Gets the name of the variable
    :vartype name: str
    :ivar data_type: Gets the data type of the variable
    :vartype data_type: str
    :ivar expression_text: Gets the expression text for computing the variable
    :vartype expression_text: str
    :ivar variable_condition_groups: Gets the variable conditions
    :vartype variable_condition_groups:
     list[~dynamics.customerinsights.api.models.MeasureVariableConditionGroup]
    """

    _validation = {
        'name': {'readonly': True},
        'data_type': {'readonly': True},
        'expression_text': {'readonly': True},
        'variable_condition_groups': {'readonly': True},
    }

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'str'},
        'expression_text': {'key': 'expressionText', 'type': 'str'},
        'variable_condition_groups': {'key': 'variableConditionGroups', 'type': '[MeasureVariableConditionGroup]'},
    }

    def __init__(self, *, kind=None, **kwargs) -> None:
        super(MeasureVariable, self).__init__(**kwargs)
        self.kind = kind
        self.name = None
        self.data_type = None
        self.expression_text = None
        self.variable_condition_groups = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HistogramBin(Model):
    """Histogram bin.

    :param lower_bound: Gets or sets the lower bound.
    :type lower_bound: float
    :param upper_bound: Gets or sets the upper bound.
    :type upper_bound: float
    :param count: Gets or sets the count.
    :type count: float
    """

    _attribute_map = {
        'lower_bound': {'key': 'lowerBound', 'type': 'float'},
        'upper_bound': {'key': 'upperBound', 'type': 'float'},
        'count': {'key': 'count', 'type': 'float'},
    }

    def __init__(self, *, lower_bound: float=None, upper_bound: float=None, count: float=None, **kwargs) -> None:
        super(HistogramBin, self).__init__(**kwargs)
        self.lower_bound = lower_bound
        self.upper_bound = upper_bound
        self.count = count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Entity(Model):
    """Entity.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param name:
    :type name: str
    :param description:
    :type description: str
    :param is_hidden:
    :type is_hidden: bool
    :ivar annotations:
    :vartype annotations:
     list[~dynamics.customerinsights.api.models.Annotation]
    """

    _validation = {
        'annotations': {'readonly': True},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'is_hidden': {'key': 'isHidden', 'type': 'bool'},
        'annotations': {'key': 'annotations', 'type': '[Annotation]'},
    }

    def __init__(self, **kwargs):
        super(Entity, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.is_hidden = kwargs.get('is_hidden', None)
        self.annotations = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstanceSearchConfiguration(Model):
    """Represents search configuration of an instance.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param entity_config: Gets search configurations for entities
    :type entity_config:
     list[~dynamics.customerinsights.api.models.EntitySearchConfiguration]
    :param is_system_generated: Gets a value indicating whether the
     configuration was system generated
    :type is_system_generated: bool
    :ivar version: Gets the version number of this object.
    :vartype version: long
    :ivar updated_by: Gets the UPN of the user who last updated this record.
    :vartype updated_by: str
    :ivar updated_utc: Gets the time the object was last updated.
    :vartype updated_utc: datetime
    :ivar created_by: Gets the email address of the user who created this
     record.
    :vartype created_by: str
    :ivar created_utc: Gets the time the object was initially created.
    :vartype created_utc: datetime
    :ivar instance_id: Gets the Customer Insights instance id associated with
     this object.
    :vartype instance_id: str
    """

    _validation = {
        'version': {'readonly': True},
        'updated_by': {'readonly': True},
        'updated_utc': {'readonly': True},
        'created_by': {'readonly': True},
        'created_utc': {'readonly': True},
        'instance_id': {'readonly': True},
    }

    _attribute_map = {
        'entity_config': {'key': 'entityConfig', 'type': '[EntitySearchConfiguration]'},
        'is_system_generated': {'key': 'isSystemGenerated', 'type': 'bool'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstanceSearchConfiguration, self).__init__(**kwargs)
        self.entity_config = kwargs.get('entity_config', None)
        self.is_system_generated = kwargs.get('is_system_generated', None)
        self.version = None
        self.updated_by = None
        self.updated_utc = None
        self.created_by = None
        self.created_utc = None
        self.instance_id = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IAttributeSearchProperties(Model):
    """IAttributeSearchProperties.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar is_searchable: Gets a value indicating whether the attribute
     supports full text search.
    :vartype is_searchable: bool
    :ivar is_filterable: Gets a value indicating whether the attribute
     supports filtering.
    :vartype is_filterable: bool
    :ivar is_facetable: Gets a value indicating whether the attribute can be
     included as facet results.
    :vartype is_facetable: bool
    :ivar is_sortable: Gets a value indicating whether the attribute can be
     included in orderby directives.
    :vartype is_sortable: bool
    :ivar facet_specification: Gets an optional specification for search
     faceting used at query time (advanced).
     this is the part behind the comma in the examples below.
     bucket facet: "price,interval:10"
     other type: "listPrice,values:10|25|100|500|1000|2500"
     value facet: city,count:5
    :vartype facet_specification: str
    """

    _validation = {
        'is_searchable': {'readonly': True},
        'is_filterable': {'readonly': True},
        'is_facetable': {'readonly': True},
        'is_sortable': {'readonly': True},
        'facet_specification': {'readonly': True},
    }

    _attribute_map = {
        'is_searchable': {'key': 'isSearchable', 'type': 'bool'},
        'is_filterable': {'key': 'isFilterable', 'type': 'bool'},
        'is_facetable': {'key': 'isFacetable', 'type': 'bool'},
        'is_sortable': {'key': 'isSortable', 'type': 'bool'},
        'facet_specification': {'key': 'facetSpecification', 'type': 'str'},
    }

    def __init__(self, **kwargs) -> None:
        super(IAttributeSearchProperties, self).__init__(**kwargs)
        self.is_searchable = None
        self.is_filterable = None
        self.is_facetable = None
        self.is_sortable = None
        self.facet_specification = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataSourceMetadata(Model):
    """Represents metadata for a Customer Insights data source.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param kind: Possible values include: 'salesforce', 'dynamics365',
     'powerQuery', 'attachCdm', 'attachCds', 'powerPlatform', 'datahub'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :ivar is_active:
    :vartype is_active: bool
    :ivar entity_names:
    :vartype entity_names: list[str]
    :ivar data_source_id: Gets the unique identity for this object.
    :vartype data_source_id: str
    :ivar name: Gets the unique name of the dataSource.
    :vartype name: str
    :ivar friendly_name: Gets the friendlyName of the dataSource.
    :vartype friendly_name: str
    :ivar entity_information: Gets the entity information, by entity name.
    :vartype entity_information:
     list[~dynamics.customerinsights.api.models.DatasourceEntityInformation]
    :param provisioning_state: Possible values include: 'new', 'creating',
     'active', 'createFailed', 'updateFailed', 'deleting',
     'refreshCredentials', 'resetInstanceInProgress'
    :type provisioning_state: str or
     ~dynamics.customerinsights.api.models.enum
    :ivar last_refresh: Gets the time datasource was last refreshed.
    :vartype last_refresh: datetime
    :param refresh_state: Possible values include: 'notUpdated', 'updated',
     'updating', 'updateFailed', 'updateCancelled'
    :type refresh_state: str or ~dynamics.customerinsights.api.models.enum
    :ivar incremental_refresh_properties: Gets the Incremental refresh
     properties for entities.
    :vartype incremental_refresh_properties:
     list[~dynamics.customerinsights.api.models.IncrementalRefreshProperties]
    :ivar model_json_path: Gets the model path for CDM data source.
    :vartype model_json_path: str
    :ivar version: Gets the version number of this object.
    :vartype version: long
    :ivar updated_by: Gets the UPN of the user who last updated this record.
    :vartype updated_by: str
    :ivar updated_utc: Gets the time the object was last updated.
    :vartype updated_utc: datetime
    :ivar created_by: Gets the email address of the user who created this
     record.
    :vartype created_by: str
    :ivar created_utc: Gets the time the object was initially created.
    :vartype created_utc: datetime
    :ivar instance_id: Gets the Customer Insights instance id associated with
     this object.
    :vartype instance_id: str
    """

    _validation = {
        'is_active': {'readonly': True},
        'entity_names': {'readonly': True},
        'data_source_id': {'readonly': True},
        'name': {'readonly': True},
        'friendly_name': {'readonly': True},
        'entity_information': {'readonly': True},
        'last_refresh': {'readonly': True},
        'incremental_refresh_properties': {'readonly': True},
        'model_json_path': {'readonly': True},
        'version': {'readonly': True},
        'updated_by': {'readonly': True},
        'updated_utc': {'readonly': True},
        'created_by': {'readonly': True},
        'created_utc': {'readonly': True},
        'instance_id': {'readonly': True},
    }

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'is_active': {'key': 'isActive', 'type': 'bool'},
        'entity_names': {'key': 'entityNames', 'type': '[str]'},
        'data_source_id': {'key': 'dataSourceId', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'entity_information': {'key': 'entityInformation', 'type': '[DatasourceEntityInformation]'},
        'provisioning_state': {'key': 'provisioningState', 'type': 'str'},
        'last_refresh': {'key': 'lastRefresh', 'type': 'iso-8601'},
        'refresh_state': {'key': 'refreshState', 'type': 'str'},
        'incremental_refresh_properties': {'key': 'incrementalRefreshProperties', 'type': '[IncrementalRefreshProperties]'},
        'model_json_path': {'key': 'modelJsonPath', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataSourceMetadata, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.is_active = None
        self.entity_names = None
        self.data_source_id = None
        self.name = None
        self.friendly_name = None
        self.entity_information = None
        self.provisioning_state = kwargs.get('provisioning_state', None)
        self.last_refresh = None
        self.refresh_state = kwargs.get('refresh_state', None)
        self.incremental_refresh_properties = None
        self.model_json_path = None
        self.version = None
        self.updated_by = None
        self.updated_utc = None
        self.created_by = None
        self.created_utc = None
        self.instance_id = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StringLengthCount(Model):
    """StringLengthCount.

    :param length: Gets or sets the string length.
    :type length: long
    :param count: Gets or sets the count of string values with the Length.
    :type count: long
    """

    _attribute_map = {
        'length': {'key': 'length', 'type': 'long'},
        'count': {'key': 'count', 'type': 'long'},
    }

    def __init__(self, **kwargs):
        super(StringLengthCount, self).__init__(**kwargs)
        self.length = kwargs.get('length', None)
        self.count = kwargs.get('count', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ValueCount(Model):
    """A value and the count of that value.

    :param value: Gets or sets the value.
    :type value: object
    :param count: Gets or sets the count of the value.
    :type count: long
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'object'},
        'count': {'key': 'count', 'type': 'long'},
    }

    def __init__(self, *, value=None, count: int=None, **kwargs) -> None:
        super(ValueCount, self).__init__(**kwargs)
        self.value = value
        self.count = count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityDataProfile(Model):
    """EntityDataProfile.

    :param qualified_entity_name:
    :type qualified_entity_name: str
    :param row_count:
    :type row_count: long
    :param quarantine_row_count:
    :type quarantine_row_count: long
    :param profiling_date:
    :type profiling_date: datetime
    :param profiled_attributes:
    :type profiled_attributes: str
    :param corrupt_attributes:
    :type corrupt_attributes: str
    """

    _attribute_map = {
        'qualified_entity_name': {'key': 'qualifiedEntityName', 'type': 'str'},
        'row_count': {'key': 'rowCount', 'type': 'long'},
        'quarantine_row_count': {'key': 'quarantineRowCount', 'type': 'long'},
        'profiling_date': {'key': 'profilingDate', 'type': 'iso-8601'},
        'profiled_attributes': {'key': 'profiledAttributes', 'type': 'str'},
        'corrupt_attributes': {'key': 'corruptAttributes', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EntityDataProfile, self).__init__(**kwargs)
        self.qualified_entity_name = kwargs.get('qualified_entity_name', None)
        self.row_count = kwargs.get('row_count', None)
        self.quarantine_row_count = kwargs.get('quarantine_row_count', None)
        self.profiling_date = kwargs.get('profiling_date', None)
        self.profiled_attributes = kwargs.get('profiled_attributes', None)
        self.corrupt_attributes = kwargs.get('corrupt_attributes', None)
